%global pypi_name hvac

# Enable Python dependency generation
%{?python_enable_dependency_generator}

%if 0%{?fedora} || 0%{?rhel} >= 8
%bcond_with     python2
%else
%bcond_without  python2
%endif

%if 0%{?fedora} || 0%{?rhel} >= 7
%bcond_without python3
%else
%bcond_with    python3
%endif

# Tests require the vault binary
%bcond_with tests
# Doc generation require the tests
%bcond_with docs

%global common_description %{expand:
Python client for HashiCorp Vault.}

Name:           python-%{pypi_name}
Summary:        HashiCorp Vault API client
Version:        0.10.0
Release:        1%{?dist}
License:        ASL 2.0

URL:            https://github.com/hvac/hvac
Source0:        %{url}/archive/v%{version}/%{pypi_name}-%{version}.tar.gz

BuildArch:      noarch


%description %{common_description}


%if %{with python2}
%package -n     python2-%{pypi_name}
Summary:        %{summary}
BuildRequires:  python2-devel
BuildRequires:  python2-setuptools
%{!?el7:BuildRequires:  python2-pyhcl}
BuildRequires:  python2-requests
BuildRequires:  python2-six
%if %{with tests}
# Tests
BuildRequires:  python2-mock
BuildRequires:  python2-requests-mock
BuildRequires:  python2-parameterized
%endif
%if %{with docs}
# Docs
BuildRequires:  python2-sphinx
BuildRequires:  python2-packaging
%endif
%{?python_provide:%python_provide python2-%{pypi_name}}

%description -n python2-%{pypi_name} %{common_description}
%endif

%if %{with python3}
%package -n      python%{python3_pkgversion}-%{pypi_name}
Summary:         %{summary}
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
%{!?el7:BuildRequires:  python%{python3_pkgversion}-pyhcl}
BuildRequires:  python%{python3_pkgversion}-requests
BuildRequires:  python%{python3_pkgversion}-six
%if %{with tests}
# Tests
BuildRequires:  python%{python3_pkgversion}-mock
BuildRequires:  python%{python3_pkgversion}-requests-mock
BuildRequires:  python%{python3_pkgversion}-parameterized
%endif
%if %{with docs}
# Docs
BuildRequires:  python%{python3_pkgversion}-sphinx
BuildRequires:  python%{python3_pkgversion}-packaging
%endif
%{?python_provide:%python_provide python%{python3_pkgversion}-%{pypi_name}}

%description -n python%{python3_pkgversion}-%{pypi_name} %{common_description}
%endif

%if %{with python3}
%if %{with docs}
%package -n     python-%{pypi_name}-doc
Summary:        %{name} documentation
%description -n python-%{pypi_name}-doc
Documentation for %{pypi_name}.
%endif
%endif


%prep
%autosetup -n %{pypi_name}-%{version}

# Remove bogus shebangs
sed -i -e 's,#!/usr/bin/python,,' hvac/api/auth_methods/aws.py
find . -name '*.py' -exec sed -i -e 's,#!/usr/bin/env python,,' {} \;

%if %{with python3}
rm -rf %{py3dir}
cp -a . %{py3dir}
%endif


%build
%if %{with python2}
%py2_build
%endif

%if %{with python3}
pushd %{py3dir}
%py3_build

%if %{with docs}
# Generate html docs
PYTHONPATH=${PWD} sphinx-build-%{python3_version} docs html

# Remove the sphinx-build leftovers
#rm -rf html/.{doctrees,buildinfo}
%endif

popd
%endif


%install
%if %{with python2}
%py2_install
%endif

%if %{with python3}
pushd %{py3dir}
%py3_install
popd
%endif

%if %{with tests}
%check
%if %{with python2}
%{__python2} setup.py test
%endif

%if %{with python3}
pushd %{py3dir}
#%{__python3} setup.py test
tox
popd
%endif
%endif


%if %{with python2}
%files -n python2-%{pypi_name}
%license LICENSE.txt
%doc CHANGELOG.md CONTRIBUTING.md README.md 
%{python2_sitelib}/%{pypi_name}/
%{python2_sitelib}/%{pypi_name}-%{version}-py%{python2_version}.egg-info/
%endif

%if %{with python3}
%files -n python%{python3_pkgversion}-%{pypi_name}
%license LICENSE.txt
%doc CHANGELOG.md CONTRIBUTING.md README.md 
%{python3_sitelib}/%{pypi_name}/
%{python3_sitelib}/%{pypi_name}-%{version}-py%{python3_version}.egg-info/
%endif

%if %{with python3}
%if %{with docs}
%files -n python-%{pypi_name}-doc
%doc html
%license LICENSE
%endif
%endif


%changelog
* Mon Mar 02 2020 Xavier Bachelot <xavier@bachelot.org> - 0.10.0-1
- Update to 0.10.0.

* Tue Feb 04 2020 Xavier Bachelot <xavier@bachelot.org> - 0.9.6-1
- Initial build.
